/*
 * SPDX-FileCopyrightText: (C) 1999-2008 Novell, Inc. (www.novell.com)
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#if !defined (__LIBECAL_H_INSIDE__) && !defined (LIBECAL_COMPILATION)
#error "Only <libecal/libecal.h> should be included directly."
#endif

#ifndef E_CAL_SYSTEM_TIMEZONE_H
#define E_CAL_SYSTEM_TIMEZONE_H

#include <glib.h>

gchar *e_cal_system_timezone_get_location (void);

#endif
