/*
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef LIBEBOOK_CONTACTS_H
#define LIBEBOOK_CONTACTS_H

#define __LIBEBOOK_CONTACTS_H_INSIDE__

#include <libedataserver/libedataserver.h>

#include <libebook-contacts/e-book-contacts-enums.h>
#include <libebook-contacts/e-book-contacts-enumtypes.h>
#include <libebook-contacts/e-book-contacts-utils.h>
#include <libebook-contacts/e-book-indices-updater.h>
#include <libebook-contacts/e-book-query.h>
#include <libebook-contacts/e-name-western.h>
#include <libebook-contacts/e-address-western.h>
#include <libebook-contacts/e-contact.h>
#include <libebook-contacts/e-vcard.h>
#include <libebook-contacts/e-source-backend-summary-setup.h>
#include <libebook-contacts/e-phone-number.h>

#include <libebook-contacts/e-book-contacts-autocleanups.h>

#undef __LIBEBOOK_CONTACTS_H_INSIDE__

#endif /* LIBEBOOK_CONTACTS_H */

