/*
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef LIBEBOOK_H
#define LIBEBOOK_H

#define __LIBEBOOK_H_INSIDE__

#include <libedataserver/libedataserver.h>
#include <libebook-contacts/libebook-contacts.h>

#include <libebook/e-book-client-view.h>
#include <libebook/e-book-client.h>
#include <libebook/e-book-enumtypes.h>
#include <libebook/e-book-types.h>
#include <libebook/e-book-utils.h>
#include <libebook/e-book-view.h>
#include <libebook/e-book.h>
#include <libebook/e-destination.h>

#include <libebook/e-book-autocleanups.h>

#undef __LIBEBOOK_H_INSIDE__

#endif /* LIBEBOOK_H */

