/*
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef LIBEDATA_BOOK_H
#define LIBEDATA_BOOK_H

#define __LIBEDATA_BOOK_H_INSIDE__

#include <libebook-contacts/libebook-contacts.h>
#include <libebackend/libebackend.h>

#include <libedata-book/e-book-backend.h>
#include <libedata-book/e-book-backend-cache.h>
#include <libedata-book/e-book-backend-factory.h>
#include <libedata-book/e-book-backend-sexp.h>
#include <libedata-book/e-book-backend-sqlitedb.h>
#include <libedata-book/e-book-backend-summary.h>
#include <libedata-book/e-book-backend-sync.h>
#include <libedata-book/e-book-cache.h>
#include <libedata-book/e-book-meta-backend.h>
#include <libedata-book/e-book-sqlite.h>
#include <libedata-book/e-data-book-cursor.h>
#include <libedata-book/e-data-book-cursor-cache.h>
#include <libedata-book/e-data-book-cursor-sqlite.h>
#include <libedata-book/e-data-book-direct.h>
#include <libedata-book/e-data-book-factory.h>
#include <libedata-book/e-data-book-view.h>
#include <libedata-book/e-data-book-view-watcher-cache.h>
#include <libedata-book/e-data-book-view-watcher-memory.h>
#include <libedata-book/e-data-book-view-watcher-sqlite.h>
#include <libedata-book/e-data-book.h>
#include <libedata-book/e-subprocess-book-factory.h>
#include <libedata-book/e-system-locale-watcher.h>

#undef __LIBEDATA_BOOK_H_INSIDE__

#endif /* LIBEDATA_BOOK_H */

