/*
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef LIBEDATA_CAL_H
#define LIBEDATA_CAL_H

#define __LIBEDATA_CAL_H_INSIDE__

#include <libecal/libecal.h>
#include <libebackend/libebackend.h>

#define LIBICAL_GLIB_UNSTABLE_API 1

#include <libedata-cal/e-cal-backend-factory.h>
#include <libedata-cal/e-cal-backend.h>
#include <libedata-cal/e-cal-backend-intervaltree.h>
#include <libedata-cal/e-cal-backend-sexp.h>
#include <libedata-cal/e-cal-backend-sync.h>
#include <libedata-cal/e-cal-backend-util.h>
#include <libedata-cal/e-cal-cache.h>
#include <libedata-cal/e-cal-meta-backend.h>
#include <libedata-cal/e-data-cal-factory.h>
#include <libedata-cal/e-data-cal.h>
#include <libedata-cal/e-data-cal-view.h>
#include <libedata-cal/e-subprocess-cal-factory.h>

#undef LIBICAL_GLIB_UNSTABLE_API

#undef __LIBEDATA_CAL_H_INSIDE__

#endif /* LIBEDATA_CAL_H */
